package com.yanzhu.jh.project.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.PublicStateEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.yanzhu.jh.project.domain.SurProjectAuditinfo;
import com.yanzhu.jh.project.mapper.SurProjectAuditinfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectCheckingMapper;
import com.yanzhu.jh.project.domain.SurProjectChecking;
import com.yanzhu.jh.project.service.ISurProjectCheckingService;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.transaction.annotation.Transactional;

/**
 * 项目验收Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2023-08-18
 */
@Service
public class SurProjectCheckingServiceImpl implements ISurProjectCheckingService 
{
    @Autowired
    private SurProjectAuditinfoMapper surProjectAuditinfoMapper;

    @Autowired
    private SurProjectCheckingMapper surProjectCheckingMapper;

    /**
     * 查询项目验收
     * 
     * @param id 项目验收主键
     * @return 项目验收
     */
    @Override
    public SurProjectChecking selectSurProjectCheckingById(Long id)
    {
        return surProjectCheckingMapper.selectSurProjectCheckingById(id);
    }

    /**
     * 查询项目验收列表
     * 
     * @param surProjectChecking 项目验收
     * @return 项目验收
     */
    @Override
    public List<SurProjectChecking> selectSurProjectCheckingList(SurProjectChecking surProjectChecking)
    {
        return surProjectCheckingMapper.selectSurProjectCheckingList(surProjectChecking);
    }

    /**
     * 统计项目验收
     *
     * @param surProjectChecking 项目验收
     * @return 项目验收集合
     */
    @Override
    public Map<String,Object> findGroupCountByApprove(SurProjectChecking surProjectChecking) {
        Map<String,Object> dataMap = new HashMap<>();
        surProjectChecking.setActiveName("jxz");
        List<SurProjectChecking> awaitList = surProjectCheckingMapper.selectSurProjectCheckingList(surProjectChecking);
        if(awaitList!=null){
            dataMap.put("jxz",awaitList.size());
        }else{
            dataMap.put("jxz",0);
        }
        surProjectChecking.setActiveName("ywc");
        List<SurProjectChecking> finishedList = surProjectCheckingMapper.selectSurProjectCheckingList(surProjectChecking);
        if(finishedList!=null){
            dataMap.put("ywc",finishedList.size());
        }else{
            dataMap.put("ywc",0);
        }
        return dataMap;
    }

    /**
     * 查询项目验收列表
     *
     * @param surProjectChecking 项目验收
     * @return 项目验收集合
     */
    @Override
    public List<SurProjectChecking> selectBgscreenProjectCheckingList(SurProjectChecking surProjectChecking) {
        return surProjectCheckingMapper.selectBgscreenProjectCheckingList(surProjectChecking);
    }

    /**
     * 查询项目验收统计
     *
     * @param surProjectChecking 项目验收
     * @return 项目验收集合
     */
    @Override
    public Map<String, Object> selectBgscreenProjectCheckingView(SurProjectChecking surProjectChecking) {
        List<Map<String, Object>> list = surProjectCheckingMapper.selectBgscreenProjectCheckingView(surProjectChecking);
        Map<String, Object> dataMap = new HashMap<>();
        int sum=0;
        int okSum=0;
        for(Map<String, Object> map:list){
            sum += Convert.toInt(map.get("total"));
            //"1"为验收合格

            if(map.get("check_result")!=null &&  "1".equals(map.get("check_result").toString())){
                okSum+=Convert.toInt(map.get("total"));
            }
        }
        dataMap.put("sum",sum);//验收数
        if(sum>0){
            dataMap.put("okSum",okSum*100/sum);//合格率
        }else{
            dataMap.put("okSum",100);//合格率
        }
        return  dataMap;
    }

    /**
     * 新增项目验收
     * 
     * @param surProjectChecking 项目验收
     * @return 结果
     */
    @Override
    @Transactional
    public int insertSurProjectChecking(SurProjectChecking surProjectChecking)
    {

        surProjectChecking.setCheckType(PublicStateEnum.PROJECT_CHECK_TYPE_JPYS.getCode());
        surProjectChecking.setWorkingPositionType(PublicStateEnum.PROJECT_CHECK_POSITION_TYPE.getCode());
        //默认第一张图是主图
        surProjectChecking.setMainImage(surProjectChecking.getImageUrls().split(",")[0]);
        surProjectChecking.setIsDel(Convert.toLong(PublicStateEnum.OK.getCode()));
        surProjectChecking.setCreateTime(DateUtils.getNowDate());

        int res = surProjectCheckingMapper.insertSurProjectChecking(surProjectChecking);
        //操作日志
        if(StringUtils.isNotBlank(surProjectChecking.getApproveStatus())){
            SurProjectAuditinfo surProjectAuditinfo = new SurProjectAuditinfo();
            surProjectAuditinfo.setFromType(PublicStateEnum.AUDIT_TYPE_JPYS.getCode());
            surProjectAuditinfo.setFromId(surProjectChecking.getId());
            surProjectAuditinfo.setApproveStatus(surProjectChecking.getApproveStatus());
            if(StringUtils.isNotBlank(surProjectChecking.getComment())){
                surProjectAuditinfo.setComment(surProjectChecking.getComment());
            }
            surProjectAuditinfo.setCreateBy(surProjectChecking.getCreateBy());
            surProjectAuditinfo.setCreateTime(new Date());
            surProjectAuditinfoMapper.insertSurProjectAuditinfo(surProjectAuditinfo);
        }

        return res;
    }

    /**
     * 修改项目验收
     * 
     * @param surProjectChecking 项目验收
     * @return 结果
     */
    @Override
    @Transactional
    public int updateSurProjectChecking(SurProjectChecking surProjectChecking)
    {
        if(surProjectChecking.getImageUrls()!=null){
            surProjectChecking.setMainImage(surProjectChecking.getImageUrls().split(",")[0]);
        }
        if(surProjectChecking.getUpdateBy()==null){
            surProjectChecking.setUpdateBy(SecurityUtils.getUsername());
        }
        surProjectChecking.setUpdateTime(DateUtils.getNowDate());

        //操作日志
        if(StringUtils.isNotBlank(surProjectChecking.getApproveStatus())){
            SurProjectAuditinfo surProjectAuditinfo = new SurProjectAuditinfo();
            surProjectAuditinfo.setFromType(PublicStateEnum.AUDIT_TYPE_JPYS.getCode());
            surProjectAuditinfo.setFromId(surProjectChecking.getId());
            surProjectAuditinfo.setApproveStatus(surProjectChecking.getApproveStatus());
            if(StringUtils.isNotBlank(surProjectChecking.getComment())){
                surProjectAuditinfo.setComment(surProjectChecking.getComment());
            }
            surProjectAuditinfo.setCreateBy(surProjectChecking.getUpdateBy());
            surProjectAuditinfo.setCreateTime(new Date());
            surProjectAuditinfoMapper.insertSurProjectAuditinfo(surProjectAuditinfo);
        }

        return surProjectCheckingMapper.updateSurProjectChecking(surProjectChecking);
    }

    /**
     * 批量删除项目验收
     * 
     * @param ids 需要删除的项目验收主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectCheckingByIds(Long[] ids)
    {
        return surProjectCheckingMapper.deleteSurProjectCheckingByIds(ids);
    }

    /**
     * 删除项目验收信息
     * 
     * @param id 项目验收主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectCheckingById(Long id)
    {
        return surProjectCheckingMapper.deleteSurProjectCheckingById(id);
    }

    /**
     * 根据项目统计项目验收信息
     *
     * @param projectId 项目主键
     * @return 结果
     */
    @Override
    public List<Map<String,Object>> findStatisticsByProjectId(Long projectId) {
        return surProjectCheckingMapper.findStatisticsByProjectId(projectId);
    }
}
